"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .userschema import UserSchema, UserSchemaTypedDict
from owasp_nest.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class PagedUserSchemaTypedDict(TypedDict):
    items: List[UserSchemaTypedDict]
    count: int


class PagedUserSchema(BaseModel):
    items: List[UserSchema]

    count: int
