"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from owasp_nest.types import BaseModel
from typing_extensions import TypedDict


class LabelSchemaTypedDict(TypedDict):
    r"""Schema for Label."""

    color: str
    description: str
    name: str


class LabelSchema(BaseModel):
    r"""Schema for Label."""

    color: str

    description: str

    name: str
