"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .labelschema import LabelSchema, LabelSchemaTypedDict
from owasp_nest.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class PagedLabelSchemaTypedDict(TypedDict):
    items: List[LabelSchemaTypedDict]
    count: int


class PagedLabelSchema(BaseModel):
    items: List[LabelSchema]

    count: int
